@@ -1,7 +1,7 @@
 """Utility functions for working and reporting on assembly data descriptors."""
 from typing import List, Union
-from ncbi.datasets.openapi.models import V1alpha1AssemblyMatch
-from ncbi.datasets.openapi.models import V1alpha1AssemblyDatasetDescriptor
+from ncbi.datasets.openapi.models import V1AssemblyMatch
+from ncbi.datasets.openapi.models import V1AssemblyDatasetDescriptor
 from ncbi.datasets.openapi import ApiClient as DatasetsApiClient
 from ncbi.datasets.openapi import GenomeApi as DatasetsGenomeApi
 from ncbi.datasets.openapi import ApiException as DatasetsApiException
@@ -9,7 +9,7 @@ from ncbi.datasets.openapi import ApiException as DatasetsApiException
 PAGE_SIZE_MAX = 1000
 
 
-def print_assembly_warning_or_error(assembly_match: V1alpha1AssemblyMatch):
+def print_assembly_warning_or_error(assembly_match: V1AssemblyMatch):
     """Reports assembly warnings and/or errors per query term
 
     Args:
@@ -24,7 +24,7 @@ def print_assembly_warning_or_error(assembly_match: V1alpha1AssemblyMatch):
     print(assembly_match.messages)
 
 
-def assembly_values_by_fields(assembly: V1alpha1AssemblyDatasetDescriptor, fields=List[str]):
+def assembly_values_by_fields(assembly: V1AssemblyDatasetDescriptor, fields=List[str]):
     """Filters assembly descriptor for provided `fields`
 
     Args:
@@ -45,8 +45,8 @@ def assembly_values_by_fields(assembly: V1alpha1AssemblyDatasetDescriptor, field
     return {fld: asm_descriptor_dict[fld] for fld in fields if fld in asm_descriptor_dict}
 
 
-def print_assembly_metadata_by_fields(assembly_match: V1alpha1AssemblyMatch, fields=List[str]):
-    """Reports selected fields for a V1alpha1AssemblyMatch object to stdout
+def print_assembly_metadata_by_fields(assembly_match: V1AssemblyMatch, fields=List[str]):
+    """Reports selected fields for a V1AssemblyMatch object to stdout
 
     Warning/Error code will be printed if the supplied assembly object does not contain a assembly field.
 
