@@ -200,14 +200,14 @@ class Dataset():
         if self.dataset_zip:
             try:
                 zinfo = self.dataset_zip.getinfo(os.path.join(self.dataset_dir, file_name))
-                with io.TextIOWrapper(self.dataset_zip.open(zinfo), encoding='utf-8') as fh:
+                with io.TextIOWrapper(self.dataset_zip.open(zinfo), encoding='utf8') as fh:
                     yield fh
             except KeyError as e:
                 logger.error('File %s not found in zipfile: %s', file_name, e)
         elif self.dataset_dir:
             file_path = os.path.join(self.dataset_dir, file_name)
             if os.path.exists(file_path):
-                with open(file_path, 'r') as fh:
+                with open(file_path, 'r', encoding='utf8') as fh:
                     yield fh
             else:
                 logger.error('File not found in datasets directory: %s', file_path)
